Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(152)

Unified Diff: bfd/cpu-metag.c

Issue 124383005: GDB 7.6.50 (Closed) Base URL: http://git.chromium.org/native_client/nacl-gdb.git@upstream
Patch Set: Created 6 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « bfd/cpu-m68k.c ('k') | bfd/cpu-mips.c » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: bfd/cpu-metag.c
diff --git a/bfd/cpu-xtensa.c b/bfd/cpu-metag.c
similarity index 75%
copy from bfd/cpu-xtensa.c
copy to bfd/cpu-metag.c
index 5c1008e9ad4c345d041b3dda6ebfc703fe1c4e8b..a8dbfaa9bfdef3da8ddfa08979a202364278374e 100644
--- a/bfd/cpu-xtensa.c
+++ b/bfd/cpu-metag.c
@@ -1,5 +1,6 @@
-/* BFD support for the Xtensa processor.
- Copyright 2003, 2005, 2007 Free Software Foundation, Inc.
+/* BFD support for the Imagination Technologies Meta processor.
+ Copyright (C) 2013 Free Software Foundation, Inc.
+ Contributed by Imagination Technologies Ltd.
This file is part of BFD, the Binary File Descriptor library.
@@ -22,17 +23,17 @@
#include "bfd.h"
#include "libbfd.h"
-const bfd_arch_info_type bfd_xtensa_arch =
+const bfd_arch_info_type bfd_metag_arch =
{
32, /* Bits per word. */
32, /* Bits per address. */
8, /* Bits per byte. */
- bfd_arch_xtensa, /* Architecture. */
- bfd_mach_xtensa, /* Machine. */
- "xtensa", /* Architecture name. */
- "xtensa", /* Printable name. */
+ bfd_arch_metag, /* Architecture. */
+ bfd_mach_metag, /* Machine. */
+ "metag", /* Architecture name. */
+ "metag", /* Printable name. */
4, /* Section align power. */
- TRUE, /* The default? */
+ TRUE, /* The default ? */
bfd_default_compatible, /* Architecture comparison fn. */
bfd_default_scan, /* String to architecture convert fn. */
bfd_arch_default_fill, /* Default fill. */
« no previous file with comments | « bfd/cpu-m68k.c ('k') | bfd/cpu-mips.c » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698